/*
 * braze.h - Common header file
 *
 * Copyright (C) 2014 Henry So, Jr.
 *
 * This file is part of Braze.
 *
 * Braze is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Braze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Braze.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _BRAZE_H
#define _BRAZE_H

#include <glib.h>

typedef struct lua_State *Scripting;

// describes how to locate a port
typedef struct {
	char *client_pattern;
	char *port_pattern;
	GRegex *client_re;
	GRegex *port_re;
	GArray *addresses;
} port_locator_t;

// describes a potential patch by its port locators
typedef struct {
	port_locator_t *source, *sink;
	int queue, time, real, exclusive;
} patch_t;

// braze.c
void abend(int exit_code, const char *__restrict __format, ...);

// patchbay.c
gboolean client_exists(const GRegex *client_re);
gboolean port_exists(const GRegex *client_re, const GRegex *port_re, gboolean input);
void reconfigure(Scripting L);
void destroy_alsa();
void initialize_alsa();
void listen_for_changes(Scripting L);

// scripting.c
void setup_for_reconfigure(Scripting L, GHashTable *locators, GHashTable *patches);
gboolean call_reconfigure_script(Scripting L, GHashTable *locators, GHashTable *patches);
void cleanup_after_reconfigure(Scripting L);
Scripting initialize_scripting(char *script);
void load_script(Scripting L);

#endif
